@@ -1,6 +1,6 @@
 matrix_to_hyp <- function(hypothesis, param_names){
   mapply(function(hyp_mat, n_ec){
-    hyps <- apply(hyp_mat[, -ncol(hyp_mat)], 1, function(x){
+    hyps <- apply(hyp_mat[, -ncol(hyp_mat), drop = FALSE], 1, function(x){
       include_term <- !x == 0
       hyp_scalar <- x[include_term]
       hyp_param <- param_names[include_term]
